S3method("%/%",fsd.fd)
S3method("*",fsd.fd)
S3method("+",fsd.fd)
S3method("-",fsd.fd)
S3method("/",fsd.fd)
S3method("[",fsd.fd)
S3method(as.fd,fsd.fd)
S3method(diff,fsd.fd)
S3method(mean,fsd.fd)
S3method(plot,fsd.fd)
export(plot.fsd.fd)
export(as.fsd.fd)
export(center.fsd.fd)
export(fsd.covariance)
export(fsd.fd)
export(fsd.filter)
export(fsd.filter.is.unilateral)
export(fsd.jb.test)
export(fsd.norm)
export(fsd.perm)
export(fsd.plot.covariance)
export(fsd.plot.data)
export(fsd.plot.filters)
export(fsd.sfarma)
export(fsd.spca)
export(fsd.spca.cov)
export(fsd.spca.filters)
export(fsd.spca.inverse)
export(fsd.spca.scores)
export(fsd.spca.var)
export(fsd.spectral.density)
export(mfsd)
export(mfsd.evaluation)
export(mfsd_Filter)
export(mfsd_Scores)
export(unfold)
import(fda)
import(mvtnorm)
import(stats)
import(Rcpp)
importFrom(Rcpp,evalCpp)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,filled.contour)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,segments)
useDynLib(MFSD)
