#' a list containing tuning parameter for the estimation of the the
#' spectral density of indian variable
#'
#' a list containing tuning parameter for the estimation of the the
#' spectral density of indian variable
#'
#'
#' @docType data
#'
#' @usage data(qlist)
#'
#'@format qlist has a dimension of 2 22
#'
#' @format An object of class \code{"matrix" "array"}.
#'
#'
#' @examples
#' data(qlist)
"qlist"
