#' a list containing the maximum lag for the filters for each
#' variable.
#'
#' an example taken from the variable indian which represents a list
#' containing the maximum lag for the filters for each variable.
#' An integer or vector of #' integers.
#'
#'
#' @docType data
#'
#' @usage data(Llist)
#'
#'@format Llist has a dimension of [1:22]
#'
#' @format An object of class \code{int [1:22]}.
#'
#' @examples
#' data(Llist)
"Llist"
