#' Spatial functional data of sea surface temperature (SST) data
#' for the year 2001, derived from NOAA optimal sea surface
#' temperature interpolation data.
#'
#' Spatial Functional Data of sea surface temperature (SST) data from the NOAA Optimum
#' Interpolation Sea Surface Temperature dataset.
#' The dataset exhibiting typical spatial dependence characterized
#' by an exponential decay.
#'
#'
#' @docType data
#'
#' @usage data(X2001)
#'
#' @format An object of class \code{"fsd.fd"}.
#'
#' @keywords datasets
#'
#'
#' @examples
#' data(X2001)
"X2001"
