#' Analyse multivariate functional spatial filters
#'
#' This function is used to analyse multivariate functional spatial filters, indicating how
#' the squared norms lie.
#' @param object containing a list of variable filters.
#' @param use.norm which norm to use for the lags.
#' @param make.plot a boolean indicating whether to plot the result.
#' @return object list with components \item{balls}{a data frame containing the
#'   cumulative sums of the squared norms of the filter coefficients up to some
#'   maximum lag.} \item{zeroplanes}{a matrix containing the sums of the squared
#'   norms of the filter coefficients lying on the (hyper-) planes with one
#'   dimension of the lag equals zero, along with the sum over all lags as
#'   comparison.} \item{abs.sum}{a data frame containing the cumulative sums of
#'   the norms of the filter coefficients.}
#' @keywords mfsd
#' @export

summary.mfsd.filter = function (object, use.norm = Inf, make.plot = FALSE)
{
  if (!inherits(object, "SM_object")) {
    stop("'object' is not a SM_object type.")
  }

  y <- length(object$filter)
  summary_mfsd = vector("list", y)
  oldClass(summary_mfsd) <- ("summary_mfsd")

  for (i in 1:y) {

    summary_mfsd[[i]] <-  summary.fsd.filter(object[["filter"]][[i]], use.norm = use.norm , make.plot = make.plot)
  }
  summary_mfsd
}
