#' Plot functional spatial filters
#'
#' This function plots functional spatial filters along a
#' two-dimensional plane of indices.
#'
#' @param x the filter object.
#' @param xlim limits of the x-axis.
#' @param ylim limits of the y-axis.
#' @param main main title of the graph.
#' @param xlab label of the x-axis.
#' @param ylab label of the y-axis.
#' @param gridsize number of grid points used to evaluate the functional data.
#' @param Npc number of filters to plot.
#' @param Lmax maximum lag to plot.
#' @param set.dims coordinates to be fixed. A vector of dimension r. `NaN`
#' represents components that are not fixed.
#' @param ... additional graphical parameters.
#'
#' @seealso \code{\link{fsd.plot.filters}}
#'
#' @method plot fsd.filter
#' @export
#' @importFrom graphics plot
#'
#' @return
#' No return value. This function is called for its side effect of
#' producing graphical displays of functional spatial filters.

plot.fsd.filter <- function(
    x,
    xlim = NULL,
    ylim = NULL,
    main = NULL,
    xlab = NULL,
    ylab = NULL,
    gridsize = NULL,
    Npc = 3,
    Lmax = 3,
    set.dims = NULL,
    ...
) {

  fsd.plot.filters(
    x,
    gridsize = gridsize,
    Npc = Npc,
    Lmax = Lmax,
    set.dims = set.dims,
    main = main,
    xlab = xlab,
    ylab = ylab
  )

}
