# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

fsd_rcpp_fourier <- function(A, lags, freq) {
    .Call('_MFSD_fsd_rcpp_fourier', PACKAGE = 'MFSD', A, lags, freq)
}

fsd_rcpp_fourier_inverse <- function(B, freq, lags) {
    .Call('_MFSD_fsd_rcpp_fourier_inverse', PACKAGE = 'MFSD', B, freq, lags)
}

