% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsd.fd.R
\name{as.fd.fsd.fd}
\alias{as.fd.fsd.fd}
\title{Converting a functional spatial data object into a functional data object}
\usage{
\method{as.fd}{fsd.fd}(x, ...)
}
\arguments{
\item{x}{a functional spatial data object}

\item{...}{currently unused}
}
\value{
An object of class \code{fd} (from the \pkg{fda} package).
The returned object corresponds to a functional data object obtained by
collapsing the spatial dimensions of the input.
The coefficients matrix represents functional observations, while the
spatial structure is removed (or flattened).
}
\description{
Works as one would expect
}
\seealso{
\code{\link{fsd.fd}}
}
\keyword{fsd}
