% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mfsd_Scores.R
\name{mfsd_Scores}
\alias{mfsd_Scores}
\title{Compute the Multivariate Scores for Spatial Functional Data.}
\usage{
mfsd_Scores(EEM, SM_vec, SM_FSD, X, J)
}
\arguments{
\item{EEM}{concatenated scores.}

\item{SM_vec}{list of variable eigenvectors.}

\item{SM_FSD}{list of univariate spatial functional principal component analysis.}

\item{X}{list of univariate spatial functional data.}

\item{J}{number of functional multivariate spatial principal components.}
}
\value{
a list of the multivariate scores.
}
\description{
Compute the Multivariate Scores for Spatial Functional Data.
}
\keyword{mfsd}
