% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsd.fd.R
\name{/.fsd.fd}
\alias{/.fsd.fd}
\title{Arithmetic for functional spatial data objects}
\usage{
\method{/}{fsd.fd}(fsdobj, scalar)
}
\arguments{
\item{fsdobj}{a functional spatial data object}

\item{scalar}{a scalar number}
}
\value{
An object of class \code{fsd.fd}.
The result corresponds to a scalar division of the functional spatial data
object, where all coefficients are divided by the given scalar.
}
\description{
Works as one would expect.
}
\keyword{fsd}
