% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qlist.R
\docType{data}
\name{qlist}
\alias{qlist}
\title{a list containing tuning parameter for the estimation of the the
spectral density of indian variable}
\format{
qlist has a dimension of 2 22

An object of class \code{"matrix" "array"}.
}
\usage{
data(qlist)
}
\description{
a list containing tuning parameter for the estimation of the the
spectral density of indian variable
}
\examples{
data(qlist)
}
\keyword{datasets}
