% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.mfsd.filter.R
\name{summary.mfsd.filter}
\alias{summary.mfsd.filter}
\title{Analyse multivariate functional spatial filters}
\usage{
\method{summary}{mfsd.filter}(object, use.norm = Inf, make.plot = FALSE)
}
\arguments{
\item{object}{containing a list of variable filters.}

\item{use.norm}{which norm to use for the lags.}

\item{make.plot}{a boolean indicating whether to plot the result.}
}
\value{
object list with components \item{balls}{a data frame containing the
  cumulative sums of the squared norms of the filter coefficients up to some
  maximum lag.} \item{zeroplanes}{a matrix containing the sums of the squared
  norms of the filter coefficients lying on the (hyper-) planes with one
  dimension of the lag equals zero, along with the sum over all lags as
  comparison.} \item{abs.sum}{a data frame containing the cumulative sums of
  the norms of the filter coefficients.}
}
\description{
This function is used to analyse multivariate functional spatial filters, indicating how
the squared norms lie.
}
\keyword{mfsd}
