% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsd.fd.R
\name{-.fsd.fd}
\alias{-.fsd.fd}
\title{Arithmetic for functional spatial data objects}
\usage{
\method{-}{fsd.fd}(fsd1, fsd2 = NULL)
}
\arguments{
\item{fsd1, fsd2}{functional spatial data objects}
}
\value{
An object of class \code{fsd.fd}.
If a single argument is provided, the result is the additive inverse of the
input object. Otherwise, it corresponds to the element-wise difference between
two functional spatial data objects.
}
\description{
Works as one would expect.
}
\keyword{fsd}
