% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.mfsd.fd.R
\name{plot.mfsd.fd}
\alias{plot.mfsd.fd}
\title{Plot method for mfsd.fd objects}
\usage{
\method{plot}{mfsd.fd}(
  x,
  xlim = NULL,
  ylim = NULL,
  main = NULL,
  xlab = NULL,
  ylab = NULL,
  gridsize = NULL,
  set.dims = NULL,
  ...
)
}
\arguments{
\item{x}{object of class mfsd.fd}

\item{xlim}{limits of x axis}

\item{ylim}{limits of y axis}

\item{main}{title}

\item{xlab}{x label}

\item{ylab}{y label}

\item{gridsize}{grid size}

\item{set.dims}{dimension selection}

\item{...}{additional graphical parameters}
}
\value{
No return value. This function is called for its side effect of
producing graphical plots of the functional spatial data.
}
\description{
Plot method for mfsd.fd objects
}
