% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Llist.R
\docType{data}
\name{Llist}
\alias{Llist}
\title{a list containing the maximum lag for the filters for each
variable.}
\format{
Llist has a dimension of [1:22]

An object of class \code{int [1:22]}.
}
\usage{
data(Llist)
}
\description{
an example taken from the variable indian which represents a list
containing the maximum lag for the filters for each variable.
An integer or vector of #' integers.
}
\examples{
data(Llist)
}
\keyword{datasets}
