% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/center.fsd.fd.R
\name{center.fsd.fd}
\alias{center.fsd.fd}
\title{Compute the centered version of spatial functional data}
\usage{
center.fsd.fd(X, margins = NULL, na.rm = FALSE)
}
\arguments{
\item{X}{The functional spatial data.}

\item{margins}{The margins for which the centering should be done separately
in every entry, in order to remove a trend.}

\item{na.rm}{Whether or not missing values should be ignored.}
}
\value{
The centered data.
}
\description{
This function is used to center spatial functional data.
}
\examples{
data("temp")

T.centered = center.fsd.fd(temp)
plot(mean(T.centered, margins = 1:2))

T.centered2 = center.fsd.fd(temp, margins = 1:2)
plot(mean(T.centered2, margins = 1:2))
plot(mean(temp, margins = 1:2))
}
\seealso{
\code{\link{mean.fsd.fd}}
}
\keyword{fsd}
