% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mfsd_Filter.R
\name{mfsd_Filter}
\alias{mfsd_Filter}
\title{Calculate the Multivariate Spectral Principal Components Filters Spatial Functional Data}
\usage{
mfsd_Filter(SM_FSD, SM_vec, J)
}
\arguments{
\item{SM_FSD}{list of univariate spatial functional principal component analysis.}

\item{SM_vec}{list of variable eigenvectors.}

\item{J}{number of functional multivariate spatial principal components.}
}
\value{
the Multivariate SPC filters.
}
\description{
This function calculates the multivariate SPC filters from a given spectral density operator.
}
\details{
The univariate eigenvectors and filters are used to compute multivariate spatial function filters.
}
\keyword{mfsd}
