% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mfsd.evaluation.R
\name{mfsd.evaluation}
\alias{mfsd.evaluation}
\title{Perform A Comparative Evaluation of Dimension Reduction: SMFPCA versus MFPCA in Multivariate Spatial Data Reconstruction}
\usage{
mfsd.evaluation(Xspec, Xspecc, X00, Npc = 3)
}
\arguments{
\item{Xspec}{an object of class SM_object, this function is obtained by applying the mfsd
function with a non-zero value of q.}

\item{Xspecc}{an object of class M_object, this object is obtained by applying the mfsd
function with q equal to zero.}

\item{X00}{a list containing the functional spatial data. Either an fd object or an array.}

\item{Npc}{the number of multivariat spatial functional principal components to be computed.}
}
\value{
a display of the NMSE and NMSE* results from \code{\link{print}}.
}
\description{
To assess the effectiveness of integrating the spatial and multivariate aspects through SMFPCA, it is
common to reconstruct the original functional data from the already computed scores and filters.
For each instance, we employ both the novel SMFPCA and the conventional MFPCA. We assess the
effectiveness of dimension reduction using the metric known as the normalized mean squared
error (NMSE) for each univariate component. NMSE* evaluates the quality of the approximation without being
influenced by grid boundary effects, unlike NMSE, where the approximation is
less accurate at the boundary.
}
\keyword{mfsd}
