% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.fsd.filter.R
\name{plot.fsd.filter}
\alias{plot.fsd.filter}
\title{Plot functional spatial filters}
\usage{
\method{plot}{fsd.filter}(
  x,
  xlim = NULL,
  ylim = NULL,
  main = NULL,
  xlab = NULL,
  ylab = NULL,
  gridsize = NULL,
  Npc = 3,
  Lmax = 3,
  set.dims = NULL,
  ...
)
}
\arguments{
\item{x}{the filter object.}

\item{xlim}{limits of the x-axis.}

\item{ylim}{limits of the y-axis.}

\item{main}{main title of the graph.}

\item{xlab}{label of the x-axis.}

\item{ylab}{label of the y-axis.}

\item{gridsize}{number of grid points used to evaluate the functional data.}

\item{Npc}{number of filters to plot.}

\item{Lmax}{maximum lag to plot.}

\item{set.dims}{coordinates to be fixed. A vector of dimension r. `NaN`
represents components that are not fixed.}

\item{...}{additional graphical parameters.}
}
\value{
No return value. This function is called for its side effect of
producing graphical displays of functional spatial filters.
}
\description{
This function plots functional spatial filters along a
two-dimensional plane of indices.
}
\seealso{
\code{\link{fsd.plot.filters}}
}
