% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsd.fd.R
\name{*.fsd.fd}
\alias{*.fsd.fd}
\title{Arithmetic for functional spatial data objects}
\usage{
\method{*}{fsd.fd}(scalar, fsdobj)
}
\arguments{
\item{scalar}{a scalar number}

\item{fsdobj}{a functional spatial data object}
}
\value{
An object of class \code{fsd.fd}.
The result corresponds to a scalar multiplication of the functional spatial
data object, where all coefficients are multiplied by the given scalar.
}
\description{
Works as one would expect.
}
\keyword{fsd}
