% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indian_2000.R
\docType{data}
\name{X2000}
\alias{X2000}
\title{Spatial functional data of sea surface temperature (SST) data
for the year 2000, derived from NOAA optimal sea surface
temperature interpolation data.}
\format{
An object of class \code{"fsd.fd"}.
}
\usage{
data(X2000)
}
\description{
Spatial Functional Data of sea surface temperature (SST) data from the NOAA Optimum
Interpolation Sea Surface Temperature dataset.
The dataset exhibiting typical spatial dependence characterized
by an exponential decay.
}
\examples{
data(X2000)
}
\keyword{datasets}
