% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fsd.fd.R
\name{+.fsd.fd}
\alias{+.fsd.fd}
\title{Arithmetic for functional spatial data objects}
\usage{
\method{+}{fsd.fd}(fsd1, fsd2)
}
\arguments{
\item{fsd1, fsd2}{functional spatial data objects}
}
\value{
An object of class \code{fsd.fd}.
The result corresponds to the element-wise sum of the coefficient arrays of
the two functional spatial data objects. The spatial structure and basis are preserved.
}
\description{
Works as one would expect.
}
\keyword{fsd}
